
% function HR= LocWhittleADG(x);
%
% Local Whittle approximation. Compute the memory parameter
% by using the extended local Whittle method 
% Details of the method are presented in: Abadir, Distaso and Giraitis (2007)
% 
% x is a trajectory of a fractional process satisfying I(d) with -0.5<d<1.5
% 
% Syntax:
%        d = LocWhittleADG(x);
%
% Input: x = observations
% 				--> m = number of samples to compute the regression
%						= N^0.65
%
% Output: d = memory parameter       
%        SN = test of stationarity using d: if SN=0, "Stationarity"  
%       NSN = test of stationarity using d: if NSN=1, "Stationarity" 
%
% The objective function is LocFun
%
% Author:     Bardet, 2012
%--------------------------------------------

function [d,SN,NSN]= LocWhittleADG(x);
x= x(:);
nx= length(x);              % number of sample
m = floor(nx^0.65);
x=x-mean(x);
y=x(2:nx);
nx=nx-1;

X= fft(y);                  % discrete Fourier transform of the samples
I= X.*conj(X);  % periodogram
I= real(I(2:(m+1)))/(2*pi*nx) ;		 % retain the m first frquencies (avoiding the 0 frequency)

lambda= 2*pi*(1:m)'/nx;     % Fourier frequencies.
lambdan=2*pi*(0.00000001+(0:(nx-1)))'/nx;
Z=X-exp(i*lambdan)./(1-exp(i*lambdan)).*(x(nx+1)-x(1));
J=Z.*conj(Z); 
J=real(J(2:(m+1)))/(2*pi*nx);
LocFun=inline('(d<0.5).*(log(mean(lambda.^(2*d).*I))-2*d*mean(log(lambda)))+(d>=0.5).*(log(mean(lambda.^(2*d).*J))-2*d*mean(log(lambda)))','d','lambda','I', 'J');

%--------------------------------------------

d= fminbnd(LocFun,-0.5,1.5,[],lambda,I,J);
%HR=d+0.5;
SN=(d>0.5+0.5*1.645/sqrt(m));
NSN=(d<0.5-0.5*1.645/sqrt(m));
%--------------------------------------------

